@@ -503,6 +503,43 @@ cat(s)
 #  # Calculate subgroup statistics.
 #  report <- numero.summary(results = stats.basic, topology = subgr)
 
+## ----eval=TRUE-----------------------------------------------------------
+# Random data matrix.
+x <- matrix(rnorm(100000), ncol=100)
+
+## ----eval=TRUE-----------------------------------------------------------
+# Create correlation modules.
+x[,12:20] <- (x[,12:20] + x[,11])
+x[,32:40] <- (x[,32:40] + x[,31])
+x[,62:90] <- (x[,62:90] + x[,61])
+x[,50] <- (x[,20] + x[,90]) # connecting node
+
+## ----eval=TRUE-----------------------------------------------------------
+# Set column names.
+cnames <- paste0("X", 1:ncol(x))
+cnames[11:20] <- paste0("M1.", cnames[11:20])
+cnames[31:40] <- paste0("M2.", cnames[31:40])
+cnames[61:90] <- paste0("M3.", cnames[61:90])
+colnames(x) <- cnames
+
+## ----eval=TRUE-----------------------------------------------------------
+# Merge collinear modules.
+y <- numero.prepare(x, coalesce=TRUE, method="")
+
+## ----eval=TRUE-----------------------------------------------------------
+# Columns that were removed or added.
+print(setdiff(colnames(x), colnames(y)))
+print(setdiff(colnames(y), colnames(x)))
+
+## ----eval=TRUE-----------------------------------------------------------
+# Show module members.
+modules <- attr(y,"pipeline")$modules
+mnames <- names(modules)
+lapply(mnames, function(k, x) {
+    cat("\n", k, "\n", sep="")
+    print(x[[k]]$weights)
+}, x=modules)
+
 ## ----echo=FALSE----------------------------------------------------------
 sessionInfo()
 Sys.time()
