@@ -5,6 +5,9 @@
 SEXP nro_circus_paint(SEXP offsets_R, SEXP topo_R, SEXP ccodes_R, SEXP key_R, SEXP title_R);
 SEXP nro_circus_show(SEXP offsets_R, SEXP topo_R, SEXP ccodes_R, SEXP labels_R, SEXP key_R);
 SEXP nro_circus_write(SEXP offsets_R, SEXP topo_R, SEXP labels_R, SEXP visible_R, SEXP contrast_R, SEXP key_R, SEXP font_R);
+SEXP nro_coalesce_network(SEXP data_R, SEXP vars_R, SEXP cutoff_R);
+SEXP nro_coalesce_prune(SEXP tails_R, SEXP heads_R, SEXP weights_R, SEXP degree_R);
+SEXP nro_coalesce_split(SEXP tails_R, SEXP heads_R, SEXP weights_R);
 SEXP nro_colorize(SEXP zvals_R, SEXP name_R);
 SEXP nro_destratify(SEXP data_R, SEXP strata_R);
 SEXP nro_diffuse(SEXP topo_R, SEXP sigma_R, SEXP bmus_R, SEXP data_R);
@@ -23,6 +26,9 @@ R_CallMethodDef callMethods[]  = {
   {"nro_circus_paint", (DL_FUNC) &nro_circus_paint, 5},
   {"nro_circus_show", (DL_FUNC) &nro_circus_show, 5},
   {"nro_circus_write", (DL_FUNC) &nro_circus_write, 7},
+  {"nro_coalesce_network", (DL_FUNC) &nro_coalesce_network, 3},
+  {"nro_coalesce_prune", (DL_FUNC) &nro_coalesce_prune, 4},
+  {"nro_coalesce_split", (DL_FUNC) &nro_coalesce_split, 3},
   {"nro_colorize", (DL_FUNC) &nro_colorize, 2},
   {"nro_destratify", (DL_FUNC) &nro_destratify, 2},
   {"nro_diffuse", (DL_FUNC) &nro_diffuse, 4},
