@@ -11,12 +11,12 @@ vector<mdsize>
 medusa::uniqsize(vector<mdsize>& items) {
   mdsize sznan = medusa::snan();
   mdsize nelem = items.size();
-  set<mdsize> bitset;
+  unordered_set<mdsize> bitset;
   vector<mdsize> mask; mask.reserve(nelem);
   for(mdsize i = 0; i < nelem; i++) {
     mdsize ind = items[i];
     if(ind == sznan) continue;
-    set<mdsize>::iterator pos = bitset.find(ind);
+    unordered_set<mdsize>::iterator pos = bitset.find(ind);
     if(pos != bitset.end()) continue;
     items[mask.size()] = ind;
     bitset.insert(ind);
