@@ -11,12 +11,11 @@ nro::vector2reals(const SEXP& data) {
   mdreal rlnan = medusa::rnan();
   vector<mdreal> array;
   NumericVector values(data);
+  LogicalVector flags = Rcpp::is_finite(values);
   mdsize nelem = values.size();
   for(mdsize i = 0; i < nelem; i++) {
-    if(NumericVector::is_na(values[i]))
-      array.push_back(rlnan);
-    else
-      array.push_back(values[i]);
+    if(flags[i]) array.push_back(values[i]);
+    else array.push_back(rlnan);
   }
   return array;
 }
